# hirakanadic

[![PyPi version](https://img.shields.io/pypi/v/hirakanadic.svg)](https://pypi.python.org/pypi/hirakanadic/)
![PyTest](https://github.com/po3rin/hirakanadic/workflows/PyTest/badge.svg)
[![](https://img.shields.io/badge/python-3.7+-blue.svg)](https://www.python.org/downloads/release/python-390/)

```sh
$ hirakanadic example/input.txt -o out.txt
```

input

```
コレステロール値
陰のうヘルニア
濾胞性リンパ腫
コリネバクテリウム・ウルセランス感染症
```

result

```
これすてろーる,5146,5146,7000,これすてろーる,名詞,普通名詞,一般,*,*,*,コレステロール,コレステロール,*,*,*,*,*
へるにあ,5146,5146,7000,へるにあ,名詞,普通名詞,一般,*,*,*,ヘルニア,ヘルニア,*,*,*,*,*
こりねばくてりうむ,5146,5146,7000,こりねばくてりうむ,名詞,普通名詞,一般,*,*,*,コリネバクテリウム,コリネバクテリウム,*,*,*,*,*
うるせらんす,5146,5146,7000,うるせらんす,名詞,普通名詞,一般,*,*,*,ウルセランス,ウルセランス,*,*,*,*,*
```
